Package 'fcp'
| Title: |
Function Composition |
| Description: |
A function composition operator to chain a series of calls
into a single function, mimicking the math notion of (f o g o
h)(x) = h(g(f(x))). Inspired by 'pipeOp' ('|>') since R4.1 and
'magrittr pipe' ('%>%'), the operator build a pipe without
putting data through, which is best for anonymous function
accepted by utilities such as apply() and lapply(). |
| Authors: |
Xiaoran Tong [aut, cre]
 |
| Maintainer: |
Xiaoran Tong <[email protected]> |
| License: |
GPL (>= 2) |
| Version: |
0.1.0 |
| Built: |
2026-05-31 08:22:50 UTC |
| Source: |
https://github.com/xiaoran831213/r_fun_comp |
Help Index